@@ -25,7 +25,7 @@ def plot_data(
     """This is the main module and it visualizes the processed data and saves it to the users computer if desired. 
 
     Args:
-        processed_data (np.array): A 2D or 3D numpy array of JWST that has been processed (not exactly sure how yet). The array will be 2D if the user gives a single .fits file and will be 3D otherwise.
+        processed_data (np.array):  Data containing the processed JWST data for the desired fits file(s)
         filename (list of strings): contains the names of the data files provided by the user
         save_image (bool): Tells the code whether the user wants the figure to be saved to their computer
         plot_method (str): Specifies whether the produced image will be an average of all the data taken using filters or a layered image
@@ -34,7 +34,7 @@ def plot_data(
                            Note that the averaging method is very slow as it has to loop over every pixel to check for dark spots (AKA no data spots)
         object_name(str): name of astronomical object being targeted
     """
-    print("Plotting beautiful figures")
+    print("Plotting beautiful figure")
 
     regridded_processed_data, old_shape_processed_data = reshaping_data(
         processed_data, filename
@@ -89,11 +89,13 @@ def simple_layer_method(
         new_processed_data[:, :, i] = (im - tmp_percentile[0]) / (
             scale_factor[i] * (tmp_percentile[1] - tmp_percentile[0])
         )
+    if len(filenames) > 1:
+        plotting_script_RGB(new_processed_data, filenames, save_image, object_name)
 
-    plotting_script(new_processed_data, filenames, save_image, object_name)
+    else:
+        plotting_script(new_processed_data, filenames, save_image, object_name)
 
 
-#
 def plotting_script(new_processed_data, filenames, save_image, object_name):
     """Contains all of the plotting code necessary to make attractive images and save them
     """
@@ -103,6 +105,32 @@ def plotting_script(new_processed_data, filenames, save_image, object_name):
 
     filters_list = get_filter_info(filenames)
 
+    fig = plt.imshow(new_processed_data, extent=extent, cmap="bone")
+    fig.axes.get_xaxis().set_visible(False)
+    fig.axes.get_yaxis().set_visible(False)
+    black_patch = mpatches.Patch(color="black", label=filters_list[0])
+    plt.legend(handles=[black_patch], loc="lower left")
+    if save_image == True:
+        print("Saving beautiful JWST image to local disk.")
+        plt.savefig(
+            object_name + ".png",  # type:ignore
+            format="png",
+            dpi=1200,
+            bbox_inches="tight",
+        )
+
+    plt.show()
+
+
+def plotting_script_RGB(new_processed_data, filenames, save_image, object_name):
+    """Contains all of the plotting code necessary to make layered RGB images of multiple wavelengths and save them
+    """
+    x = new_processed_data[0, :, 0]
+    y = new_processed_data[:, 0, 0]
+    extent = 0, len(x), 0, len(y)
+
+    filters_list = get_filter_info(filenames)
+
     fig = plt.imshow(new_processed_data, extent=extent)
     fig.axes.get_xaxis().set_visible(False)
     fig.axes.get_yaxis().set_visible(False)
@@ -111,6 +139,7 @@ def plotting_script(new_processed_data, filenames, save_image, object_name):
     bluepatch = mpatches.Patch(color="blue", label=filters_list[2])
     plt.legend(handles=[red_patch, bluepatch, greenpatch], loc="lower left")
     if save_image == True:
+        print("Saving beautiful JWST image to local disk.")
         plt.savefig(
             object_name + ".png",  # type:ignore
             format="png",
@@ -156,15 +185,21 @@ def reshaping_data(processed_data, filename):
     for i in range(len(processed_data[:, 0, 0])):
         correct_shape_processed_data[:, :, i] = processed_data[i, :, :]
 
-    # regridding images (i.e aligning them properly in space)
-    regridded_processed_data = regrid_images(correct_shape_processed_data, filename)
+    # regridding images (i.e aligning them properly in space) if more than one image is given
+    if len(filename) > 1:
+        regridded_processed_data = regrid_images(
+            correct_shape_processed_data, filename
+        )  # type:ignore
+
+    else:
+        regridded_processed_data = correct_shape_processed_data
 
     old_shape_pd = np.zeros(
         (
             (
-                len(correct_shape_processed_data[0, 0, :]),
-                len(correct_shape_processed_data[:, 0, 0]),
-                len(correct_shape_processed_data[0, :, 0]),
+                len(processed_data[:, 0, 0]),
+                len(processed_data[0, :, 0]),
+                len(processed_data[0, 0, :]),
             )
         )
     )
@@ -200,6 +235,7 @@ def alpha_layer_images(
             img.flatten(), [1, 99]
         )  # 12 and 99 were determined by trial and error
         alpha_val = 0.333  # alpha determines the opacity of each layer
+        plt.figure(2)
         plt.imshow(
             img, vmin=vmin, vmax=vmax, cmap=cmap_list[i], alpha=alpha_val, extent=extent
         )
